@@ -114,6 +114,8 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
         Update Apache configuration file or not.
         If this is first-time deploy, the value will be forced to True.
     """
+    # TODO: Create database if not exists
+
     # Get deploy settings and project name
     global gitignores, pyc_pattern, raw_gitignores, project_src_root_gitignore
     execute(deploy_setting, project_name=project_name,
@@ -265,7 +267,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
 
             # Replace gitignore. We wanna preserve pyc
             project_src_root_gitignore = os.path.join(project_src_root, '.gitignore')
-            pyc_pattern = re.compile(r'.*\.py[c|o]$')
+            pyc_pattern = re.compile(r'.*\.py[c|o|\[co\]]$')
             gitignores = []
             with open(project_src_root_gitignore, 'r') as f:
                 raw_gitignores = f.read().strip().split('\n')
@@ -498,6 +500,11 @@ def deploy_to_remote():
         if clean_py:
             target_run('find %s -name \'*.py\' -exec rm -rf {} \;'%remote_project_source_root)
 
+    # DB migrate
+    with fab_settings(virtual_env(remote_project_venv), target_cd(remote_project_source_root)):
+        target_run('python manage.py syncdb --noinput')
+        target_run('python manage.py migrate')
+
     # Install WSGI
     apache_conf_updated = False
     if deploy_settings.get('INSTALL_APACHE_CONF') and update_apache_conf:
