@@ -61,7 +61,7 @@ class DictModel(models.Model):
             self._fields = [field.name for field in self.__class__._meta.fields]
         return self._fields
 
-    def dict(self, json_serializable=False, summary=False):
+    def dict(self, json_serializable=False, expand_choices=False, **kwargs):
         """Convert a model into dict
         :return: a dictionary containing fields name and values in this model
         """
@@ -71,9 +71,15 @@ class DictModel(models.Model):
             result = dict([item for item in self.items() if item[0] in json_serializable_fields])
         else:
             result = dict(self.items())
+
+        if expand_choices:
+            for field, value in result.items():
+                if hasattr(self, 'get_%s_display'%field.lower()):
+                    result[field] = getattr(self, 'get_%s_display'%field.lower())()
+
         return result
 
-    def json_dict(self, use_float_seconds=True, summary=False):
+    def json_dict(self, use_float_seconds=True, summary=False, **kwargs):
         """Convert a model into dict which is json serializable.
 
         DateTimeField and DateField will be converted into a unix-timestamp-like object.
@@ -83,7 +89,8 @@ class DictModel(models.Model):
 
         :return: a dictionary which is json serializable
         """
-        return json_model_dict(self.dict(json_serializable=True, summary=summary), use_float_seconds=use_float_seconds)
+        return json_model_dict(self.dict(json_serializable=True, summary=summary, **kwargs),
+            use_float_seconds=use_float_seconds)
 
     class Meta:
         abstract = True
