@@ -1,5 +1,2 @@
 from eggplant.models.fields.json_field import JSONField
-
-__all__ = [
-    JSONField.__name__,
-]
\ No newline at end of file
+from django_fields.fields import *
